/*
Code for Arduino ATMEGA/ESP32 slave sender.

The code is a simulation of an I2C slave device for demonstration purposes.
Instead of getting temperature values from a real sensor,
we will insert our own values. If you have an actual sensor, you can simply replace
the inserted values by those from the sensor.

Author : Vincent Chanengeta

*/

#include <Wire.h>

float temperature;
int data[2];
byte sensorAdd = 8;

void setup() 
{
  Serial.begin(115200);
  Wire.begin(sensorAdd); // join i2c bus with address #8
  Wire.onRequest(requestEvent); // register event
}

void loop() 
{
  
  temperature = myTemperature(); // we suppose that myTemperature() is your sensor function
  delay(2000);
  
}


void requestEvent() 
{
  //The wire can only transfer 1 byte at a time.
  //We need to send temperature values in 2 bytes since temperature is a float, but the values are sent as integers.
  //If the temperature is 25.42 °C, we send a byte with 25, and another byte with 42.

  data[0] = temperature;
  data[1] = (temperature - data[0])*100;

  for (int i = 0; i < 2; i++)
  {
    Wire.write(data[i]);
  } 
}


//----------------------------------------------------------------------------------------
//My functions

float myTemperature() //the function generates random temperature values (sensor simulation).
{
   float temp;

   temp = random(22, 30) + (float)(random(0, 99))/100;

   return temp;
  
}
